pub struct JoinError { /* private fields */ }Expand description
Error in polling JoinHandle.
Implementations
Sourceimpl JoinError
impl JoinError
Sourcepub fn try_into_panic(self) -> Result<Box<dyn Any + Send + 'static>, JoinError>
pub fn try_into_panic(self) -> Result<Box<dyn Any + Send + 'static>, JoinError>
Consumes this into panic if it represents a panic error.
Sourcepub fn into_panic(self) -> Box<dyn Any + Send + 'static>
pub fn into_panic(self) -> Box<dyn Any + Send + 'static>
Consumes this into panic if it represents a panic error, panic otherwise.
Sourcepub fn resume_panic(self) -> !
pub fn resume_panic(self) -> !
Resumes the catched panic if it represents a panic error, otherwise panic with error reason.
Sourcepub fn is_cancelled(&self) -> bool
pub fn is_cancelled(&self) -> bool
Returns true if task is cancelled.